@@ -117,7 +117,20 @@ assign_labels.data.frame <- function(x, ..., .missing = c("error", "warn", "skip
 #' @export
 #' @rdname labels
 assign_label <- function(x, ...) {
-  .Deprecated("assign_label")
+  msg <- collapse0(
+    "`mark::assign_label()` is deprecated.",
+    "Use `mark::assign_labels()` instead.",
+    "This function will be removed in mark 0.5.1",
+    sep = "\n"
+  )
+  cond <- warningCondition(
+    message = msg,
+    old = "assign_label()",
+    new = "assign_labels()",
+    package = "mark",
+    class = "deprecatedWarning"
+  )
+  warning(cond)
   assign_labels(x, ...)
 }
 
